@@ -13,12 +13,12 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-from elements import *
-import parser
-from blockdiag.utils import XY
+from actdiag import parser
+from actdiag.elements import (Diagram, DiagramNode, DiagramEdge, NodeGroup)
+from blockdiag.utils import unquote, XY
 
 
-class DiagramTreeBuilder:
+class DiagramTreeBuilder(object):
     def build(self, tree):
         self.diagram = Diagram()
         diagram = self.instantiate(self.diagram, tree)
@@ -344,9 +344,9 @@ class DiagramLayoutManager:
         return True
 
 
-class ScreenNodeBuilder:
+class ScreenNodeBuilder(object):
     @classmethod
-    def build(klass, tree, separate=False):
+    def build(cls, tree, separate=False):
         DiagramNode.clear()
         DiagramEdge.clear()
         NodeGroup.clear()
@@ -356,12 +356,12 @@ class ScreenNodeBuilder:
         diagram.fixiate(True)
 
         if diagram.orientation == 'portrait':
-            klass.rotate_diagram(diagram)
+            cls.rotate_diagram(diagram)
 
         return diagram
 
     @classmethod
-    def rotate_diagram(klass, diagram):
+    def rotate_diagram(cls, diagram):
         for node in diagram.traverse_nodes():
             node.xy = XY(node.xy.y, node.xy.x)
             node.colwidth, node.colheight = (node.colheight, node.colwidth)
