@@ -272,6 +272,18 @@ class TestRstDirectives(unittest2.TestCase):
         self.assertEqual(1, len(doctree))
         self.assertEqual(nodes.image, type(doctree[0]))
 
+    @use_tmpdir
+    def test_block_max_width_inline_svg(self, path):
+        directives.setup(format='SVG', outputdir=path,
+                         nodoctype=True, noviewbox=True, inline_svg=True)
+        text = ".. actdiag::\n   :maxwidth: 100\n\n   { A -> B }"
+        doctree = publish_doctree(text)
+        self.assertEqual(1, len(doctree))
+        self.assertEqual(nodes.raw, type(doctree[0]))
+        self.assertEqual(nodes.Text, type(doctree[0][0]))
+        self.assertRegexpMatches(doctree[0][0],
+                                 '<svg height="\d+" width="100" ')
+
     @use_tmpdir
     def test_block_inline_svg_true_with_multibytes(self, path):
         directives.setup(format='SVG', outputdir=path,
